@@ -1,4 +1,4 @@
-from duty.cli import get_parser
+from duty import get_parser
 
 parser = get_parser()
 print(f"```\n{parser.format_help()}\n```")
