@@ -6,13 +6,13 @@ from runpy import run_module
 
 old_argv = list(sys.argv)
 sys.argv = ["mkdocs"]
-old_stdout = sys.stdout
-sys.stdout = StringIO()
+old_stderr = sys.stderr
+sys.stderr = StringIO()
 warnings.filterwarnings("ignore", category=RuntimeWarning)
 with suppress(SystemExit):
     run_module("mkdocs", run_name="__main__")
-output = sys.stdout.getvalue()
-sys.stdout = old_stdout
+output = sys.stderr.getvalue()
+sys.stderr = old_stderr
 sys.argv = old_argv
 
 print(f"```\n{output}\n```")
